@@ -1,11 +1,13 @@
 package Org::Element::RadioTarget;
 
+our $DATE = '2014-11-18'; # DATE
+our $VERSION = '0.41'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 extends 'Org::Element';
-
-our $VERSION = '0.40'; # VERSION
+with 'Org::Element::InlineRole';
 
 has target => (is => 'rw');
 
@@ -25,6 +27,10 @@ sub as_string {
          "<<<", $self->target, ">>>");
 }
 
+sub as_text {
+    goto \&as_string;
+}
+
 1;
 # ABSTRACT: Represent Org radio target
 
@@ -40,19 +46,27 @@ Org::Element::RadioTarget - Represent Org radio target
 
 =head1 VERSION
 
-This document describes version 0.40 of Org::Element::RadioTarget (from Perl distribution Org-Parser), released on 2014-08-28.
+This document describes version 0.41 of Org::Element::RadioTarget (from Perl distribution Org-Parser), released on 2014-11-18.
 
 =head1 DESCRIPTION
 
 Derived from L<Org::Element>.
 
+=for Pod::Coverage ^(BUILD)$
+
 =head1 ATTRIBUTES
 
 =head2 target
 
 =head1 METHODS
 
-=for Pod::Coverage as_string BUILD
+=head2 as_string => str
+
+From L<Org::Element>.
+
+=head2 as_text => str
+
+From L<Org::Element::InlineRole>.
 
 =head1 HOMEPAGE
 
