@@ -1,11 +1,13 @@
 package Org::Element::TimeRange;
 
+our $DATE = '2014-11-18'; # DATE
+our $VERSION = '0.41'; # VERSION
+
 use 5.010;
 use locale;
 use Moo;
 extends 'Org::Element';
-
-our $VERSION = '0.40'; # VERSION
+with 'Org::Element::InlineRole';
 
 has ts1 => (is => 'rw');
 has ts2 => (is => 'rw');
@@ -20,6 +22,10 @@ sub as_string {
      );
 }
 
+sub as_text {
+    goto \&as_string;
+}
+
 1;
 # ABSTRACT: Represent Org time range (TS1--TS2)
 
@@ -35,7 +41,7 @@ Org::Element::TimeRange - Represent Org time range (TS1--TS2)
 
 =head1 VERSION
 
-This document describes version 0.40 of Org::Element::TimeRange (from Perl distribution Org-Parser), released on 2014-08-28.
+This document describes version 0.41 of Org::Element::TimeRange (from Perl distribution Org-Parser), released on 2014-11-18.
 
 =head1 DESCRIPTION
 
@@ -53,7 +59,13 @@ Ending timestamp.
 
 =head1 METHODS
 
-=for Pod::Coverage as_string
+=head2 as_string => str
+
+From L<Org::Element>.
+
+=head2 as_text => str
+
+From L<Org::Element::InlineRole>.
 
 =head1 HOMEPAGE
 
