@@ -1,12 +1,14 @@
 package Org::Element::Timestamp;
 
+our $DATE = '2014-11-18'; # DATE
+our $VERSION = '0.41'; # VERSION
+
 use 5.010;
 use locale;
 use utf8;
 use Moo;
 extends 'Org::Element';
-
-our $VERSION = '0.40'; # VERSION
+with 'Org::Element::InlineRole';
 
 my @attrs = (qw/datetime has_time event_duration recurrence is_active/);
 for (@attrs) {
@@ -70,6 +72,10 @@ sub as_string {
      );
 }
 
+sub as_text {
+    goto \&as_string;
+}
+
 sub _parse_timestamp {
     require DateTime;
     require DateTime::Event::Recurrence;
@@ -203,7 +209,7 @@ Org::Element::Timestamp - Represent Org timestamp
 
 =head1 VERSION
 
-This document describes version 0.40 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2014-08-28.
+This document describes version 0.41 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2014-11-18.
 
 =head1 DESCRIPTION
 
@@ -247,8 +253,6 @@ event_duration is 7200+600=7800 (2 hours 10 minutes).
 
 =head1 METHODS
 
-=for Pod::Coverage as_string
-
 =head2 $el->clear_parse_result
 
 Clear parse result.
@@ -260,6 +264,14 @@ You can do this prior to serializing the object.
 Timestamp will automatically be parsed again from _str when one of the
 attributes is accessed.
 
+=head2 as_string => str
+
+From L<Org::Element>.
+
+=head2 as_text => str
+
+From L<Org::Element::InlineRole>.
+
 =head1 BUGS AND LIMITATIONS
 
 =over
